@@ -32,9 +32,9 @@ class Drawer:
 
     def make_color(self, length_range, length):
         has_special = (
-            self.poster.special_number["special_number2"]
+            self.poster.special_number.get("special_number2", length)
             < length
-            < self.poster.special_number["special_number1"]
+            < self.poster.special_number.get("special_number1", length)
         )
         color_from = (
             self.poster.colors["special"]
@@ -117,7 +117,7 @@ class Drawer:
             index = 0
             for _type in self.poster.type_list:
                 num = day_tracks.get(_type)
-                length_range = self.poster.length_range_by_date_dict.get(_type)
+                length_range = self.poster.length_range_by_date_dict.get(_type, 1)
                 if not num:
                     continue
                 dom = dom_tuple[index]
