@@ -2,11 +2,13 @@ from github_poster.loader.bilibili_loader import BilibiliLoader
 from github_poster.loader.cichang_loader import CiChangLoader
 from github_poster.loader.dota2_loader import Dota2Loader
 from github_poster.loader.duolingo_loader import DuolingoLoader
+from github_poster.loader.forest_loader import ForestLoader
 from github_poster.loader.from_github_issue_loader import GitHubIssuesLoader
 from github_poster.loader.garmin_loader import GarminLoader
 from github_poster.loader.github_loader import GitHubLoader
 from github_poster.loader.gitlab_loader import GitLabLoader
 from github_poster.loader.gpx_loader import GPXLoader
+from github_poster.loader.json_loader import JsonLoader
 from github_poster.loader.kindle_loader import KindleLoader
 from github_poster.loader.leetcode_loader import LeetcodeLoader
 from github_poster.loader.multiple_loader import MutipleLoader
@@ -17,7 +19,6 @@ from github_poster.loader.strava_loader import StravaLoader
 from github_poster.loader.twitter_loader import TwitterLoader
 from github_poster.loader.wakatime_loader import WakaTimeLoader
 from github_poster.loader.youtube_loader import YouTubeLoader
-from github_poster.loader.json_loader import JsonLoader
 
 LOADER_DICT = {
     "duolingo": DuolingoLoader,
@@ -39,6 +40,7 @@ LOADER_DICT = {
     "multiple": MutipleLoader,
     "nike": NRCLoader,
     "garmin": GarminLoader,
+    "forest": ForestLoader,
     "json": JsonLoader,
 }
 
@@ -62,6 +64,7 @@ __all__ = (
     "MutipleLoader",
     "NRCLoader",
     "LOADER_DICT",
+    "ForestLoader",
     "GarminLoader",
     "JsonLoader",
 )
